@@ -81,7 +81,7 @@ def BorderCheck(X, ub, lb, pop, dim):
     return X
 
 
-def CaculateFitness(X, fun, args):
+def CalculateFitness(X, fun, args):
     """
     The fitness calculating function.
 
@@ -109,7 +109,7 @@ def CaculateFitness(X, fun, args):
     return fitness,res_l
 
 
-def CaculateFitness_MV(Xs, fun, args):
+def CalculateFitness_MV(Xs, fun, args):
     """
     The fitness calculating function for multi-variable tasks.
 
@@ -151,7 +151,7 @@ def CaculateFitness_MV(Xs, fun, args):
     return fitness, res_l
 
 
-def CaculateFitnessMP(X, fun, n_jobs, args):
+def CalculateFitnessMP(X, fun, n_jobs, args):
     """
     The fitness calculating function for multi-processing tasks.
 
@@ -170,7 +170,7 @@ def CaculateFitnessMP(X, fun, n_jobs, args):
     return fitness,res_l
 
 
-def CaculateFitnessMP_MV(Xs, fun, n_jobs, args):
+def CalculateFitnessMP_MV(Xs, fun, n_jobs, args):
     """
     The fitness calculating function for multi-variable & multi-processing tasks.
 
@@ -312,7 +312,7 @@ def run(pop, dim, lb, ub, MaxIter,  fun,RecordPath = None, args=()):
         hf = []
         hr = []
         X, lb, ub = initial(pop, dim, ub, lb)
-        fitness,res = CaculateFitness(X, fun, args)
+        fitness,res = CalculateFitness(X, fun, args)
         hr.append(res)
         hs.append(copy.copy(X))
         hf.append(copy.copy(fitness))
@@ -375,7 +375,7 @@ def run(pop, dim, lb, ub, MaxIter,  fun,RecordPath = None, args=()):
 
 
         X = BorderCheck(X, ub, lb, pop, dim)
-        fitness, res = CaculateFitness(X, fun, args)
+        fitness, res = CalculateFitness(X, fun, args)
 
         # merge the flame and moth
         fitnessM = np.concatenate([fitnessS,fitness],axis=0)
@@ -398,7 +398,7 @@ def run(pop, dim, lb, ub, MaxIter,  fun,RecordPath = None, args=()):
                 Tub = np.max(XElite, 0)
                 XOppo = np.array([random.random() * (Tlb + Tub) - XElite[j, :] for j in range(EliteNumber)])
                 XOppo = BorderCheck(XOppo, ub, lb, EliteNumber, dim)
-                fitOppo, resOppo = CaculateFitness(XOppo, fun, args)
+                fitOppo, resOppo = CalculateFitness(XOppo, fun, args)
                 for j in range(EliteNumber):
                     if fitOppo[j] < fitnessS[j]:
                         fitnessS[j] = copy.copy(fitOppo[j])
@@ -486,7 +486,7 @@ def runMP(pop, dim, lb, ub, MaxIter, fun, n_jobs,RecordPath = None, args=()):
         hr = []
 
         X, lb, ub = initial(pop, dim, ub, lb)
-        fitness, res = CaculateFitnessMP(X, fun,n_jobs, args)
+        fitness, res = CalculateFitnessMP(X, fun,n_jobs, args)
         hr.append(res)
         hs.append(copy.copy(X))
         hf.append(copy.copy(fitness))
@@ -547,7 +547,7 @@ def runMP(pop, dim, lb, ub, MaxIter, fun, n_jobs,RecordPath = None, args=()):
                     X[i, j] = distance_to_flame * np.exp(b * r) * np.cos(r * 2 * math.pi) + Xs[Flame_no - 1, j]
 
         X = BorderCheck(X, ub, lb, pop, dim)
-        fitness, res = CaculateFitnessMP(X, fun,n_jobs, args)
+        fitness, res = CalculateFitnessMP(X, fun,n_jobs, args)
         # merged
         #fitnessM = np.concatenate([fitness_previous, fitness], axis=0)
         #resM = np.concatenate([res_previous, res], axis=0)
@@ -577,7 +577,7 @@ def runMP(pop, dim, lb, ub, MaxIter, fun, n_jobs,RecordPath = None, args=()):
 
                 XOppo = np.array([random.random() * (Tlb + Tub) - XElite[j, :] for j in range(EliteNumber)])
                 XOppo = BorderCheck(XOppo, ub, lb, EliteNumber, dim)
-                fitOppo, resOppo = CaculateFitnessMP(XOppo, fun,n_jobs, args)
+                fitOppo, resOppo = CalculateFitnessMP(XOppo, fun,n_jobs, args)
                 for j in range(EliteNumber):
                     if fitOppo[j] < fitnessS[j]:
                         fitnessS[j] = copy.copy(fitOppo[j])
@@ -653,7 +653,7 @@ def run_MV(pop, dims, lbs, ubs, MaxIter, fun,RecordPath = None, args=()):
         hrs = [[] for i in range(num_var)]
 
         X, lbs, ubs = initial_MV(pop, dims, ubs, lbs)
-        fitness,res = CaculateFitness_MV(X, fun, args)
+        fitness,res = CalculateFitness_MV(X, fun, args)
         Xs = copy.copy(X)
         fitnessS = copy.copy(fitness)
         resS = copy.copy(res)
@@ -721,7 +721,7 @@ def run_MV(pop, dims, lbs, ubs, MaxIter, fun,RecordPath = None, args=()):
 
         for n in range(num_var):
             X[n] = BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
-        fitness, res = CaculateFitness_MV(X, fun, args)
+        fitness, res = CalculateFitness_MV(X, fun, args)
 
         for n in range(num_var):
             fitnessM = np.concatenate([fitnessS[n],fitness[n]],axis=0)
@@ -747,7 +747,7 @@ def run_MV(pop, dims, lbs, ubs, MaxIter, fun,RecordPath = None, args=()):
                 XOppo = [np.array([random.random() * (Tlb[n] + Tub[n]) - XElite[n][j, :] for j in range(EliteNumber)]) for n in range(num_var)]
                 for n in range(num_var):
                     XOppo[n] = BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
-                fitOppo, resOppo = CaculateFitness_MV(XOppo, fun, args)
+                fitOppo, resOppo = CalculateFitness_MV(XOppo, fun, args)
                 for j in range(EliteNumber):
                     for n in range(num_var):
                         if fitOppo[n][j] < fitness[n][j]:
@@ -835,7 +835,7 @@ def runMP_MV(pop, dims, lbs, ubs, MaxIter, fun,n_jobs,RecordPath = None, args=()
         hfs = [[] for i in range(num_var)]
         hrs = [[] for i in range(num_var)]
         X, lbs, ubs = initial_MV(pop, dims, ubs, lbs)
-        fitness,res = CaculateFitnessMP_MV(X, fun,n_jobs, args)
+        fitness,res = CalculateFitnessMP_MV(X, fun,n_jobs, args)
         Xs = copy.copy(X)
         fitnessS = copy.copy(fitness)
         resS = copy.copy(res)
@@ -903,7 +903,7 @@ def runMP_MV(pop, dims, lbs, ubs, MaxIter, fun,n_jobs,RecordPath = None, args=()
 
         for n in range(num_var):
             X[n] = BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
-        fitness, res = CaculateFitnessMP_MV(X, fun,n_jobs, args)
+        fitness, res = CalculateFitnessMP_MV(X, fun,n_jobs, args)
 
         for n in range(num_var):
             fitnessM = np.concatenate([fitnessS[n],fitness[n]],axis=0)
@@ -928,7 +928,7 @@ def runMP_MV(pop, dims, lbs, ubs, MaxIter, fun,n_jobs,RecordPath = None, args=()
                 XOppo = [np.array([random.random() * (Tlb[n] + Tub[n]) - XElite[n][j, :] for j in range(EliteNumber)]) for n in range(num_var)]
                 for n in range(num_var):
                     XOppo[n] = BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
-                fitOppo, resOppo = CaculateFitnessMP_MV(XOppo, fun,n_jobs, args)
+                fitOppo, resOppo = CalculateFitnessMP_MV(XOppo, fun,n_jobs, args)
                 for j in range(EliteNumber):
                     for n in range(num_var):
                         if fitOppo[n][j] < fitness[n][j]:
