@@ -85,7 +85,7 @@ def BorderCheck(X, ub, lb, pop, dim):
     return X
 
 
-def CaculateFitness(X,fun,args):
+def CalculateFitness(X,fun,args):
     """
     The fitness calculating function.
 
@@ -113,7 +113,7 @@ def CaculateFitness(X,fun,args):
     return fitness,res_l
 
 
-def CaculateFitness_MV(Xs, fun, args):
+def CalculateFitness_MV(Xs, fun, args):
     """
     The fitness calculating function for multi-variable tasks.
 
@@ -155,7 +155,7 @@ def CaculateFitness_MV(Xs, fun, args):
     return fitness, res_l
 
 
-def CaculateFitnessMP(X,fun,n_jobs,args):
+def CalculateFitnessMP(X,fun,n_jobs,args):
     """
     The fitness calculating function for multi-processing tasks.
 
@@ -174,7 +174,7 @@ def CaculateFitnessMP(X,fun,n_jobs,args):
     return fitness,res_l
 
 
-def CaculateFitnessMP_MV(Xs, fun, n_jobs, args):
+def CalculateFitnessMP_MV(Xs, fun, n_jobs, args):
     """
     The fitness calculating function for multi-variable & multi-processing tasks.
 
@@ -321,7 +321,7 @@ def run(pop,dim,lb,ub,MaxIter,fun,Vmin=None,Vmax=None,RecordPath = None,args=())
 
         X,lb,ub = initial(pop, dim, ub, lb)
         V,Vmin,Vmax = initial(pop, dim, Vmax, Vmin)
-        fitness,res = CaculateFitness(X,fun,args)
+        fitness,res = CalculateFitness(X,fun,args)
         hr.append(res)
         hs.append(copy.copy(X))
         hf.append(copy.copy(fitness))
@@ -378,7 +378,7 @@ def run(pop,dim,lb,ub,MaxIter,fun,Vmin=None,Vmax=None,RecordPath = None,args=())
 
 
         X = BorderCheck(X, ub, lb, pop, dim)
-        fitness, res = CaculateFitness(X, fun, args)
+        fitness, res = CalculateFitness(X, fun, args)
         fitness, sortIndex = SortFitness(fitness)
         X = SortPosition(X, sortIndex)
         Pbest = SortPosition(Pbest,sortIndex)
@@ -395,7 +395,7 @@ def run(pop,dim,lb,ub,MaxIter,fun,Vmin=None,Vmax=None,RecordPath = None,args=())
                 # 更新精英反向解
                 XOppo = np.array([random.random() * (Tlb + Tub) - XElite[j, :] for j in range(EliteNumber)])
                 XOppo = BorderCheck(XOppo, ub, lb, EliteNumber, dim)
-                fitOppo, resOppo = CaculateFitness(XOppo, fun, args)
+                fitOppo, resOppo = CalculateFitness(XOppo, fun, args)
                 for j in range(EliteNumber):
                     if fitOppo[j] < fitness[j]:
                         fitness[j] = copy.copy(fitOppo[j])
@@ -499,7 +499,7 @@ def runMP(pop, dim, lb, ub, MaxIter, fun,n_jobs, Vmin = None, Vmax = None,Record
 
         X, lb, ub = initial(pop, dim, ub, lb)
         V, Vmin, Vmax = initial(pop, dim, Vmax, Vmin)
-        fitness, res = CaculateFitnessMP(X, fun, n_jobs, args)
+        fitness, res = CalculateFitnessMP(X, fun, n_jobs, args)
         hr.append(res)
         hs.append(copy.copy(X))
         hf.append(copy.copy(fitness))
@@ -554,7 +554,7 @@ def runMP(pop, dim, lb, ub, MaxIter, fun,n_jobs, Vmin = None, Vmax = None,Record
 
 
         X = BorderCheck(X, ub, lb, pop, dim)
-        fitness, res = CaculateFitnessMP(X, fun,n_jobs, args)
+        fitness, res = CalculateFitnessMP(X, fun,n_jobs, args)
         fitness, sortIndex = SortFitness(fitness)
         X = SortPosition(X, sortIndex)
         Pbest = SortPosition(Pbest,sortIndex)
@@ -571,7 +571,7 @@ def runMP(pop, dim, lb, ub, MaxIter, fun,n_jobs, Vmin = None, Vmax = None,Record
 
                 XOppo = np.array([random.random() * (Tlb + Tub) - XElite[j, :] for j in range(EliteNumber)])
                 XOppo = BorderCheck(XOppo,ub,lb,EliteNumber,dim)
-                fitOppo,resOppo = CaculateFitnessMP(XOppo,fun,n_jobs,args)
+                fitOppo,resOppo = CalculateFitnessMP(XOppo,fun,n_jobs,args)
                 for j in range(EliteNumber):
                     if fitOppo[j] < fitness[j]:
                         fitness[j] = copy.copy(fitOppo[j])
@@ -663,7 +663,7 @@ def run_MV(pop,dims,lbs,ubs,MaxIter,fun,Vmin=None,Vmax=None,RecordPath = None,ar
 
         X,lbs,ubs = initial_MV(pop, dims, ubs, lbs)
         V,Vmin,Vmax = initial_MV(pop, dims, Vmax, Vmin)
-        fitness,res = CaculateFitness_MV(X,fun,args)
+        fitness,res = CalculateFitness_MV(X,fun,args)
         for i in range(num_var):
             hrs[i].append(res[i])
             hss[i].append(copy.copy(X[i]))
@@ -724,7 +724,7 @@ def run_MV(pop,dims,lbs,ubs,MaxIter,fun,Vmin=None,Vmax=None,RecordPath = None,ar
 
         for n in range(num_var):
             X[n] = BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
-        fitness, res = CaculateFitness_MV(X, fun, args)
+        fitness, res = CalculateFitness_MV(X, fun, args)
         for n in range(num_var):
             fitness[n], sortIndex = SortFitness(fitness[n])
             X[n] = SortPosition(X[n], sortIndex)
@@ -743,7 +743,7 @@ def run_MV(pop,dims,lbs,ubs,MaxIter,fun,Vmin=None,Vmax=None,RecordPath = None,ar
                 XOppo = [np.array([random.random() * (Tlb[n] + Tub[n]) - XElite[n][j, :] for j in range(EliteNumber)]) for n in range(num_var)]
                 for n in range(num_var):
                     XOppo[n] = BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
-                fitOppo, resOppo = CaculateFitness_MV(XOppo, fun, args)
+                fitOppo, resOppo = CalculateFitness_MV(XOppo, fun, args)
                 for j in range(EliteNumber):
                     for n in range(num_var):
                         if fitOppo[n][j] < fitness[n][j]:
@@ -847,7 +847,7 @@ def runMP_MV(pop,dims,lbs,ubs,MaxIter, fun,n_jobs,Vmin=None,Vmax=None,RecordPath
 
         X,lbs,ubs = initial_MV(pop, dims, ubs, lbs)
         V,Vmin,Vmax = initial_MV(pop, dims, Vmax, Vmin)
-        fitness,res = CaculateFitnessMP_MV(X,fun,n_jobs,args)
+        fitness,res = CalculateFitnessMP_MV(X,fun,n_jobs,args)
         for i in range(num_var):
             hrs[i].append(res[i])
             hss[i].append(copy.copy(X[i]))
@@ -907,7 +907,7 @@ def runMP_MV(pop,dims,lbs,ubs,MaxIter, fun,n_jobs,Vmin=None,Vmax=None,RecordPath
 
         for n in range(num_var):
             X[n] = BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
-        fitness, res = CaculateFitnessMP_MV(X, fun,n_jobs, args)
+        fitness, res = CalculateFitnessMP_MV(X, fun,n_jobs, args)
         for n in range(num_var):
             fitness[n], sortIndex = SortFitness(fitness[n])
             X[n] = SortPosition(X[n], sortIndex)
@@ -926,7 +926,7 @@ def runMP_MV(pop,dims,lbs,ubs,MaxIter, fun,n_jobs,Vmin=None,Vmax=None,RecordPath
                 XOppo = [np.array([random.random() * (Tlb[n] + Tub[n]) - XElite[n][j, :] for j in range(EliteNumber)]) for n in range(num_var)]
                 for n in range(num_var):
                     XOppo[n] = BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
-                fitOppo, resOppo = CaculateFitnessMP_MV(XOppo, fun,n_jobs, args)
+                fitOppo, resOppo = CalculateFitnessMP_MV(XOppo, fun,n_jobs, args)
                 for j in range(EliteNumber):
                     for n in range(num_var):
                         if fitOppo[n][j] < fitness[n][j]:
