@@ -81,7 +81,7 @@ def BorderCheck(X,ub,lb,pop,dim):
     return X
 
 
-def CaculateFitness(X,fun,args):
+def CalculateFitness(X,fun,args):
     """
     The fitness calculating function.
 
@@ -109,7 +109,7 @@ def CaculateFitness(X,fun,args):
     return fitness,res_l
 
 
-def CaculateFitnessMP(X,fun,n_jobs,args):
+def CalculateFitnessMP(X,fun,n_jobs,args):
     """
     The fitness calculating function for multi-processing tasks.
 
@@ -128,7 +128,7 @@ def CaculateFitnessMP(X,fun,n_jobs,args):
     return fitness,res_l
 
 
-def CaculateFitness_MV(Xs, fun, args):
+def CalculateFitness_MV(Xs, fun, args):
     """
     The fitness calculating function for multi-variable tasks.
 
@@ -170,7 +170,7 @@ def CaculateFitness_MV(Xs, fun, args):
     return fitness, res_l
 
 
-def CaculateFitnessMP_MV(Xs, fun, n_jobs, args):
+def CalculateFitnessMP_MV(Xs, fun, n_jobs, args):
     """
     The fitness calculating function for multi-variable & multi-processing tasks.
 
@@ -310,7 +310,7 @@ def run(pop,dim,lb,ub,MaxIter,fun,fc=None,RecordPath = None,args=()):
         hf = []
         hr = []
         X, lb, ub = initial(pop, dim, ub, lb)
-        fitness, res = CaculateFitness(X, fun,args)
+        fitness, res = CalculateFitness(X, fun,args)
         hr.append(res)
         hs.append(copy.copy(X))
         hf.append(copy.copy(fitness))
@@ -379,7 +379,7 @@ def run(pop,dim,lb,ub,MaxIter,fun,fc=None,RecordPath = None,args=()):
             X_new[j, :] = x * y * z * DS[j, :] + Pbest
 
         X_new = BorderCheck(X_new, ub, lb, pop, dim)
-        fitness, res = CaculateFitness(X_new, fun,args)
+        fitness, res = CalculateFitness(X_new, fun,args)
         fitness, sortIndex = SortFitness(fitness)
         X = SortPosition(X_new, sortIndex)
         res = SortPosition(res, sortIndex)
@@ -394,7 +394,7 @@ def run(pop,dim,lb,ub,MaxIter,fun,fc=None,RecordPath = None,args=()):
 
                 XOppo = np.array([random.random() * (Tlb + Tub) - XElite[j, :] for j in range(EliteNumber)])
                 XOppo = BorderCheck(XOppo, ub, lb, EliteNumber, dim)
-                fitOppo, resOppo = CaculateFitness(XOppo, fun,args)
+                fitOppo, resOppo = CalculateFitness(XOppo, fun,args)
                 for j in range(EliteNumber):
                     if fitOppo[j] < fitness[j]:
                         fitness[j] = copy.copy(fitOppo[j])
@@ -483,7 +483,7 @@ def runMP(pop, dim, lb, ub, MaxIter,  fun, n_jobs,fc=None,RecordPath = None,args
         hf = []
         hr = []
         X, lb, ub = initial(pop, dim, ub, lb)
-        fitness, res = CaculateFitnessMP(X, fun,n_jobs,args)
+        fitness, res = CalculateFitnessMP(X, fun,n_jobs,args)
         hr.append(res)
         hs.append(copy.copy(X))
         hf.append(copy.copy(fitness))
@@ -551,7 +551,7 @@ def runMP(pop, dim, lb, ub, MaxIter,  fun, n_jobs,fc=None,RecordPath = None,args
 
 
         X_new = BorderCheck(X_new, ub, lb, pop, dim)
-        fitness, res = CaculateFitnessMP(X_new, fun,n_jobs, args)
+        fitness, res = CalculateFitnessMP(X_new, fun,n_jobs, args)
         fitness, sortIndex = SortFitness(fitness)
         X = SortPosition(X_new, sortIndex)
         res = SortPosition(res, sortIndex)
@@ -566,7 +566,7 @@ def runMP(pop, dim, lb, ub, MaxIter,  fun, n_jobs,fc=None,RecordPath = None,args
 
                 XOppo = np.array([random.random() * (Tlb + Tub) - XElite[j, :] for j in range(EliteNumber)])
                 XOppo = BorderCheck(XOppo, ub, lb, EliteNumber, dim)
-                fitOppo, resOppo = CaculateFitnessMP(XOppo, fun,n_jobs, args)
+                fitOppo, resOppo = CalculateFitnessMP(XOppo, fun,n_jobs, args)
                 for j in range(EliteNumber):
                     if fitOppo[j] < fitness[j]:
                         fitness[j] = copy.copy(fitOppo[j])
@@ -645,7 +645,7 @@ def run_MV(pop,dims,lbs,ubs,MaxIter,fun,fc=None,RecordPath = None,args=()):
         hfs = [[] for i in range(num_var)]
         hrs = [[] for i in range(num_var)]
         X,lbs,ubs = initial_MV(pop, dims, ubs, lbs)
-        fitness,res = CaculateFitness_MV(X,fun,args)
+        fitness,res = CalculateFitness_MV(X,fun,args)
         for i in range(num_var):
             hrs[i].append(res[i])
             hss[i].append(copy.copy(X[i]))
@@ -717,7 +717,7 @@ def run_MV(pop,dims,lbs,ubs,MaxIter,fun,fc=None,RecordPath = None,args=()):
 
         for n in range(num_var):
             X_new[n] = BorderCheck(X_new[n], ubs[n], lbs[n], pop, dims[n])
-        fitness, res = CaculateFitness_MV(X_new, fun,args)
+        fitness, res = CalculateFitness_MV(X_new, fun,args)
         for n in range(num_var):
             fitness[n], sortIndex = SortFitness(fitness[n])
             X[n] = SortPosition(X_new[n], sortIndex)
@@ -734,7 +734,7 @@ def run_MV(pop,dims,lbs,ubs,MaxIter,fun,fc=None,RecordPath = None,args=()):
                 XOppo = [np.array([random.random() * (Tlb[n] + Tub[n]) - XElite[n][j, :] for j in range(EliteNumber)]) for n in range(num_var)]
                 for n in range(num_var):
                     XOppo[n] = BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
-                fitOppo, resOppo = CaculateFitness_MV(XOppo, fun, args)
+                fitOppo, resOppo = CalculateFitness_MV(XOppo, fun, args)
                 for j in range(EliteNumber):
                     for n in range(num_var):
                         if fitOppo[n][j] < fitness[n][j]:
@@ -827,7 +827,7 @@ def runMP_MV(pop,dims,lbs,ubs,MaxIter,fun, n_jobs,fc=None,RecordPath = None,args
         hfs = [[] for i in range(num_var)]
         hrs = [[] for i in range(num_var)]
         X,lbs,ubs = initial_MV(pop, dims, ubs, lbs)
-        fitness,res = CaculateFitnessMP_MV(X,fun,n_jobs,args)
+        fitness,res = CalculateFitnessMP_MV(X,fun,n_jobs,args)
         for i in range(num_var):
             hrs[i].append(res[i])
             hss[i].append(copy.copy(X[i]))
@@ -899,7 +899,7 @@ def runMP_MV(pop,dims,lbs,ubs,MaxIter,fun, n_jobs,fc=None,RecordPath = None,args
 
         for n in range(num_var):
             X_new[n] = BorderCheck(X_new[n], ubs[n], lbs[n], pop, dims[n])
-        fitness, res = CaculateFitnessMP_MV(X_new, fun,n_jobs,args)
+        fitness, res = CalculateFitnessMP_MV(X_new, fun,n_jobs,args)
         for n in range(num_var):
             fitness[n], sortIndex = SortFitness(fitness[n])
             X[n] = SortPosition(X_new[n], sortIndex)
@@ -916,7 +916,7 @@ def runMP_MV(pop,dims,lbs,ubs,MaxIter,fun, n_jobs,fc=None,RecordPath = None,args
                 XOppo = [np.array([random.random() * (Tlb[n] + Tub[n]) - XElite[n][j, :] for j in range(EliteNumber)]) for n in range(num_var)]
                 for n in range(num_var):
                     XOppo[n] = BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
-                fitOppo, resOppo = CaculateFitnessMP_MV(XOppo, fun,n_jobs, args)
+                fitOppo, resOppo = CalculateFitnessMP_MV(XOppo, fun,n_jobs, args)
                 for j in range(EliteNumber):
                     for n in range(num_var):
                         if fitOppo[n][j] < fitness[n][j]:
