@@ -80,7 +80,7 @@ def BorderCheck(X, ub, lb, pop, dim):
     return X
 
 
-def CaculateFitness(X,fun,args):
+def CalculateFitness(X,fun,args):
     """
     The fitness calculating function.
 
@@ -108,7 +108,7 @@ def CaculateFitness(X,fun,args):
     return fitness,res_l
 
 
-def CaculateFitnessMP(X, fun, n_jobs, args):
+def CalculateFitnessMP(X, fun, n_jobs, args):
     """
     The fitness calculating function for multi-processing tasks.
 
@@ -127,7 +127,7 @@ def CaculateFitnessMP(X, fun, n_jobs, args):
     return fitness,res_l
 
 
-def CaculateFitness_MV(Xs, fun, args):
+def CalculateFitness_MV(Xs, fun, args):
     """
     The fitness calculating function for multi-variable tasks.
 
@@ -169,7 +169,7 @@ def CaculateFitness_MV(Xs, fun, args):
     return fitness, res_l
 
 
-def CaculateFitnessMP_MV(Xs, fun, n_jobs, args):
+def CalculateFitnessMP_MV(Xs, fun, n_jobs, args):
     """
     The fitness calculating function for multi-variable & multi-processing tasks.
 
@@ -307,7 +307,7 @@ def run(pop, dim, lb, ub, MaxIter, fun, RecordPath = None, args=()):
         hf = []
         hr = []
         X, lb, ub = initial(pop, dim, ub, lb)
-        fitness,res = CaculateFitness(X, fun,args)
+        fitness,res = CalculateFitness(X, fun,args)
         hr.append(res)
         hs.append(copy.copy(X))
         hf.append(copy.copy(fitness))
@@ -371,7 +371,7 @@ def run(pop, dim, lb, ub, MaxIter, fun, RecordPath = None, args=()):
 
 
         X = BorderCheck(X, ub, lb, pop, dim)
-        fitness,res = CaculateFitness(X, fun,args)
+        fitness,res = CalculateFitness(X, fun,args)
         fitness, sortIndex = SortFitness(fitness)
         X = SortPosition(X, sortIndex)
         res = SortPosition(res, sortIndex)
@@ -386,7 +386,7 @@ def run(pop, dim, lb, ub, MaxIter, fun, RecordPath = None, args=()):
 
                 XOppo = np.array([random.random() * (Tlb + Tub) - XElite[j, :] for j in range(EliteNumber)])
                 XOppo = BorderCheck(XOppo, ub, lb, EliteNumber, dim)
-                fitOppo, resOppo = CaculateFitness(XOppo, fun, args)
+                fitOppo, resOppo = CalculateFitness(XOppo, fun, args)
                 for j in range(EliteNumber):
                     if fitOppo[j] < fitness[j]:
                         fitness[j] = copy.copy(fitOppo[j])
@@ -473,7 +473,7 @@ def runMP(pop, dim, lb, ub, MaxIter, fun,n_jobs, RecordPath = None, args=()):
         hf = []
         hr = []
         X, lb, ub = initial(pop, dim, ub, lb)
-        fitness, res = CaculateFitnessMP(X, fun,n_jobs, args)
+        fitness, res = CalculateFitnessMP(X, fun,n_jobs, args)
         hr.append(res)
         hs.append(copy.copy(X))
         hf.append(copy.copy(fitness))
@@ -539,7 +539,7 @@ def runMP(pop, dim, lb, ub, MaxIter, fun,n_jobs, RecordPath = None, args=()):
 
 
         X = BorderCheck(X, ub, lb, pop, dim)
-        fitness,res = CaculateFitnessMP(X, fun,n_jobs,args)
+        fitness,res = CalculateFitnessMP(X, fun,n_jobs,args)
         fitness, sortIndex = SortFitness(fitness)
         X = SortPosition(X, sortIndex)
         res = SortPosition(res, sortIndex)
@@ -553,7 +553,7 @@ def runMP(pop, dim, lb, ub, MaxIter, fun,n_jobs, RecordPath = None, args=()):
                 Tub = np.max(XElite, 0)
                 XOppo = np.array([random.random() * (Tlb + Tub) - XElite[j, :] for j in range(EliteNumber)])
                 XOppo = BorderCheck(XOppo, ub, lb, EliteNumber, dim)
-                fitOppo, resOppo = CaculateFitnessMP(XOppo, fun, n_jobs, args)
+                fitOppo, resOppo = CalculateFitnessMP(XOppo, fun, n_jobs, args)
                 for j in range(EliteNumber):
                     if fitOppo[j] < fitness[j]:
                         fitness[j] = copy.copy(fitOppo[j])
@@ -628,7 +628,7 @@ def run_MV(pop, dims, lbs, ubs, MaxIter, fun, RecordPath = None, args=()):
         hfs = [[] for i in range(num_var)]
         hrs = [[] for i in range(num_var)]
         X,lbs,ubs = initial_MV(pop, dims, ubs, lbs)
-        fitness,res = CaculateFitness_MV(X,fun,args)
+        fitness,res = CalculateFitness_MV(X,fun,args)
         for i in range(num_var):
             hrs[i].append(res[i])
             hss[i].append(copy.copy(X[i]))
@@ -698,7 +698,7 @@ def run_MV(pop, dims, lbs, ubs, MaxIter, fun, RecordPath = None, args=()):
 
         for n in range(num_var):
             X[n] = BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
-        fitness, res = CaculateFitness_MV(X, fun, args)
+        fitness, res = CalculateFitness_MV(X, fun, args)
         for n in range(num_var):
             fitness[n], sortIndex = SortFitness(fitness[n])
             X[n] = SortPosition(X[n], sortIndex)
@@ -715,7 +715,7 @@ def run_MV(pop, dims, lbs, ubs, MaxIter, fun, RecordPath = None, args=()):
                 XOppo = [np.array([random.random() * (Tlb[n] + Tub[n]) - XElite[n][j, :] for j in range(EliteNumber)]) for n in range(num_var)]
                 for n in range(num_var):
                     XOppo[n] = BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
-                fitOppo, resOppo = CaculateFitness_MV(XOppo, fun, args)
+                fitOppo, resOppo = CalculateFitness_MV(XOppo, fun, args)
                 for j in range(EliteNumber):
                     for n in range(num_var):
                         if fitOppo[n][j] < fitness[n][j]:
@@ -801,7 +801,7 @@ def runMP_MV(pop, dims, lbs, ubs, MaxIter, fun,n_jobs,RecordPath = None, args=()
         hfs = [[] for i in range(num_var)]
         hrs = [[] for i in range(num_var)]
         X,lbs,ubs = initial_MV(pop, dims, ubs, lbs)
-        fitness,res = CaculateFitnessMP_MV(X,fun,n_jobs,args)
+        fitness,res = CalculateFitnessMP_MV(X,fun,n_jobs,args)
         for i in range(num_var):
             hrs[i].append(res[i])
             hss[i].append(copy.copy(X[i]))
@@ -871,7 +871,7 @@ def runMP_MV(pop, dims, lbs, ubs, MaxIter, fun,n_jobs,RecordPath = None, args=()
 
         for n in range(num_var):
             X[n] = BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
-        fitness, res = CaculateFitnessMP_MV(X, fun,n_jobs, args)
+        fitness, res = CalculateFitnessMP_MV(X, fun,n_jobs, args)
         for n in range(num_var):
             fitness[n], sortIndex = SortFitness(fitness[n])
             X[n] = SortPosition(X[n], sortIndex)
@@ -888,7 +888,7 @@ def runMP_MV(pop, dims, lbs, ubs, MaxIter, fun,n_jobs,RecordPath = None, args=()
                 XOppo = [np.array([random.random() * (Tlb[n] + Tub[n]) - XElite[n][j, :] for j in range(EliteNumber)]) for n in range(num_var)]
                 for n in range(num_var):
                     XOppo[n] = BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
-                fitOppo, resOppo = CaculateFitnessMP_MV(XOppo, fun,n_jobs, args)
+                fitOppo, resOppo = CalculateFitnessMP_MV(XOppo, fun,n_jobs, args)
                 for j in range(EliteNumber):
                     for n in range(num_var):
                         if fitOppo[n][j] < fitness[n][j]:
