@@ -19,10 +19,11 @@ from . import MFO
 from . import MODE
 from . import NSGA2
 from . import utilize
+from . import TOPSIS
 
 
 
 __all__ = ['evaluation_metrics','utilize', 'multi_jobs','plot','progress_bar',
            'sampling','save','test_functions','uncertainty_analysis_fun',
            'WOA','TSA','SCA','SOA','SSA','PSO','GLUE','GWO','MFO',
-           'MOPSO','MODE','NSGA2','template']
\ No newline at end of file
+           'MOPSO','MODE','NSGA2','template', 'TOPSIS']
\ No newline at end of file
